@@ -198,10 +198,10 @@ class KeyboardModels:
             'ru'                      : [N_('keyboard|Russian'), 'us,ru', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'sr-cy'                 : [N_('keyboard|Serbian'), 'cs', 'pc105', '', ''],
+            'sr-cy'                 : [N_('keyboard|Serbian'), 'rs', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'sr-latin'                 : [N_('keyboard|Serbian (latin)'), 'cs', 'pc105', 'latin', ''],
+            'sr-latin'                 : [N_('keyboard|Serbian (latin)'), 'rs', 'pc105', 'latin', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'sv-latin1'               : [N_('keyboard|Swedish'), 'se', 'pc105', '', ''],
@@ -237,7 +237,7 @@ class KeyboardModels:
             'us-acentos'              : [N_('keyboard|U.S. International'), 'us', 'pc105', 'intl', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'us'                      : [N_('keyboard|U.S. English'), 'us+inet', 'pc105', '', ''],
+            'us'                      : [N_('keyboard|U.S. English'), 'us', 'pc105', '', ''],
             }
 
     def _get_models(self):
